@@ -114,8 +114,8 @@ mod tests {
 
     #[test]
     fn inline_test() {
-        let md = "*italic* **bold** ~~del~~ ^sup^ ~sub~ ~_underline_~".to_string();
-        let html = "<p><em>italic</em> <strong>bold</strong> <del>del</del> <sup>sup</sup> <sub>sub</sub> <u>underline</u></p>";
+        let md = "*italic* **bold** ~~del~~ ^sup^ ~sub~ ~_underline_~ `code`".to_string();
+        let html = "<p><em>italic</em> <strong>bold</strong> <del>del</del> <sup>sup</sup> <sub>sub</sub> <u>underline</u> <code class=\"short\">code</code></p>";
 
         assert_eq!(
             html.trim_end_matches('\n'),
