@@ -5,6 +5,7 @@ mod list;
 mod table;
 mod blockquote;
 mod paragraph;
+mod toc;
 mod inline;
 mod escape;
 mod syntax_highlighter;
@@ -21,6 +22,7 @@ use paragraph::merge_paragraph;
 use table::merge_table;
 use blockquote::merge_blockquote;
 use list::merge_list;
+use toc::{collect_headers, render_toc};
 
 
 pub fn render(content: &String) -> Result<String, ()> {
@@ -32,6 +34,10 @@ pub fn render(content: &String) -> Result<String, ()> {
 
     let mut lines = code_to_lines(&u16_content);
     lines = merge_code_fence(&lines, &syntax_highlighter);
+
+    let headers = collect_headers(&lines);
+
+    lines = render_toc(&lines, &headers);
     lines = render_independent_tag(&lines);
     lines = render_inlines(lines);
 
