@@ -43,7 +43,7 @@ pub fn render_inline(mut line: Line) -> Line {
     match line.line_type {
         LineType::FencedCode | LineType::CodeFence | LineType::ThematicBreak
         | LineType::Empty | LineType::TableDelimiter | LineType::RenderedTable
-        | LineType::Tag => line,
+        | LineType::Tag | LineType::Toc => line,
 
         LineType::Paragraph | LineType::Header | LineType::Blockquote(_)
         | LineType::OrderedList | LineType::UnorderedList => {
