@@ -1,5 +1,6 @@
 use crate::markdown::line::{Line, LineType};
 use crate::consts::*;
+use crate::utils::into_v16;
 
 
 pub fn merge_paragraph(lines: &Vec<Line>) -> Vec<Line> {
@@ -47,7 +48,7 @@ fn construct_paragraph(paragraph: Vec<&Line>) -> Line {
             if p.content.len() > 2
             && p.content[p.content.len() - 1] == U16_SPACE
             && p.content[p.content.len() - 2] == U16_SPACE  {
-                contents.push(vec![U16_LESS_THAN, U16_SMALL_B, U16_SMALL_R, U16_SPACE, U16_SLASH, U16_GREATER_THAN]);
+                contents.push(into_v16("<br />"));
             }
 
             else {
